//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/InstrumentWidgets/InstrumentListModel.h
//! @brief     Defines class InstrumentListModel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_INSTRUMENTLISTMODEL_H
#define BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_INSTRUMENTLISTMODEL_H

#include <QAbstractListModel>
#include <QIcon>

class InstrumentItem;
class InstrumentModel;

class InstrumentListModel : public QAbstractListModel {
    Q_OBJECT

public:
    InstrumentListModel(InstrumentModel* instruments, QObject* parent = nullptr);

    virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;

    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;

    InstrumentItem* instrumentForIndex(const QModelIndex& index) const;

    QModelIndex addNewGISASInstrument();

    QModelIndex addNewOffSpecularInstrument();

    QModelIndex addNewSpecularInstrument();

    QModelIndex addNewDepthProbeInstrument();

    void removeInstrument(const QModelIndex& index);

    QModelIndex copyInstrument(const QModelIndex& source);

    QModelIndex copyInstrument(const InstrumentItem* source);

private:
    template <class Instrument> QModelIndex addNewInstrument();

private:
    InstrumentModel* m_instruments;

    QIcon m_gisasIcon;
    QIcon m_offSpecularIcon;
    QIcon m_specularIcon;
    QIcon m_depthProbeIcon;
};

#endif // BORNAGAIN_GUI_VIEWS_INSTRUMENTWIDGETS_INSTRUMENTLISTMODEL_H
